@@ -32,8 +32,6 @@
 #define OnigUChar unsigned char
 #endif
 
-void saphire_get_quoted_fname_readline_ver(char* file, string_obj* ret);
-
 typedef struct {
     string_obj* mName;
 
@@ -120,26 +118,6 @@ static BOOL name_sort(void* left, void* right)
 
     return strcasecmp(lfname, rfname) < 0;
 }
-void saphire_get_quoted_fname_readline_ver(char* file, string_obj* ret)
-{
-    string_obj* tmp = STRING_NEW("");
-    saphire_get_quoted_fname(file, tmp);
-
-    /// ~のクォートを除外 ///
-    char* p = string_c_str(tmp);
-    
-    while(*p) {
-        if(*p == '\\' && *(p+1) == '~') {
-            p++;
-            string_push_back2(ret, *p++);
-        }
-        else {
-            string_push_back2(ret, *p++);
-        }
-    }
-
-    string_delete(tmp);
-}
 
 
 static string_obj* gEditingDir;
@@ -376,10 +354,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
     else if(same_point == strlen(text)) {
         char tmp[PATH_MAX];
         xstrncpy(tmp, file, PATH_MAX);
-        string_obj* tmp2 = STRING_NEW("");
-        saphire_get_quoted_fname_readline_ver(tmp, tmp2);
-        char* ret = strdup(string_c_str(tmp2));
-        string_delete(tmp2);
+        char* ret = strdup(tmp);
 
         return ret;
     }
@@ -450,10 +425,7 @@ char* readline_file_completion_migemo_match(char* text, char* file)
     if(r2 == 0) {
         char tmp[PATH_MAX];
         xstrncpy(tmp, file, PATH_MAX);
-        string_obj* tmp2 = STRING_NEW("");
-        saphire_get_quoted_fname_readline_ver(tmp, tmp2);
-        char* ret = strdup(string_c_str(tmp2));
-        string_delete(tmp2);
+        char* ret = strdup(tmp);
 
         return ret;
     }
@@ -664,10 +636,7 @@ char* readline_file_completion_migemo(const char* text, int rstat)
             char path[PATH_MAX];
             xstrncpy(path, file, PATH_MAX);
 
-            string_obj* tmp2 = STRING_NEW("");
-            saphire_get_quoted_fname_readline_ver(path, tmp2);
-            char* ret = strdup(string_c_str(tmp2));
-            string_delete(tmp2);
+            char* ret = strdup(path);
 
             struct stat stat_;
             xstrncpy(path, string_c_str(gEditingDir), PATH_MAX);
@@ -1031,10 +1000,7 @@ char* readline_file_completion(const char* text, int rstat)
             char path[PATH_MAX];
             xstrncpy(path, file, PATH_MAX);
 
-            string_obj* tmp2 = STRING_NEW("");
-            saphire_get_quoted_fname_readline_ver(path, tmp2);
-            char* ret = strdup(string_c_str(tmp2));
-            string_delete(tmp2);
+            char* ret = strdup(path);
 
             struct stat stat_;
             xstrncpy(path, string_c_str(gEditingDir),  PATH_MAX);
@@ -2318,16 +2284,10 @@ static int readline_select_file(int count, int key)
                             , cursor_path+strlen(cwd_path)
                             , strlen(cursor_path) - strlen(cwd_path)+1);
 
-                        string_obj* quoted_fname = STRING_NEW("");
-                        saphire_get_quoted_fname_readline_ver(cursor_path2, quoted_fname);
-                        rl_insert_text(string_c_str(quoted_fname));
-                        string_delete(quoted_fname);
+                        rl_insert_text(cursor_path2);
                     }
                     else {
-                        string_obj* quoted_fname = STRING_NEW("");
-                        saphire_get_quoted_fname_readline_ver(cursor_path, quoted_fname);
-                        rl_insert_text(string_c_str(quoted_fname));
-                        string_delete(quoted_fname);
+                        rl_insert_text(cursor_path);
                     }
                 }
                 else {
@@ -2345,20 +2305,13 @@ static int readline_select_file(int count, int key)
                                 , strlen(full_path) - strlen(cwd_path));
                             full_path2[strlen(full_path) - strlen(cwd_path)] = 0;
 
-                            string_obj* quoted_fname = STRING_NEW("");
-                            saphire_get_quoted_fname_readline_ver
-                                (full_path2, quoted_fname);
-                            rl_insert_text(string_c_str(quoted_fname));
-                            string_delete(quoted_fname);
+                            rl_insert_text(full_path2);
 
                             if(j<vector_size(mark_files)-1) 
                                 rl_insert_text(" ");
                         }
                         else {
-                            string_obj* quoted_fname = STRING_NEW("");
-                            saphire_get_quoted_fname_readline_ver(full_path, quoted_fname);
-                            rl_insert_text(string_c_str(quoted_fname));
-                            string_delete(quoted_fname);
+                            rl_insert_text(full_path);
 
                             if(j<vector_size(mark_files)-1) 
                                 rl_insert_text(" ");
@@ -2452,7 +2405,7 @@ void readline_init()
     rl_attempted_completion_function = readline_on_complete;
     rl_completer_quote_characters = "\"'";
     rl_completer_word_break_characters = " \t\n\"'|{}!&;()<>=%/";
-    rl_filename_quote_characters = " \\\t\n\"|$*?[]!<>{}&;#()'%";
+    rl_filename_quote_characters = " \\\t\n\"|$*?[]!<>{}&;#()'%~";
     rl_completion_append_character= ' ';
     rl_char_is_quoted_p = (rl_linebuf_func_t*)lftp_char_is_quoted;
     rl_filename_quoting_function = bash_quote_filename;
