@@ -8,14 +8,16 @@ extern volatile BOOL gSigUser;
 
 /// ޥɤбʸ
 enum eCommandKind { 
+    kVar, kGlobal, kExport, 
+    kAry, kAryAdd, kAryErase, 
+    kHash, kHashAdd, kHashErase,  
     kSubshell, kMSleep, kTrue, kFalse, kTest,
     kIndex, kRIndex, kLength, kLc, kUc,
-    kChomp, kSubstr, kEval, kFg, kBg, kCpg,
-    kJobs, kRehash, kKanjiCode, kLineField, kVar, kGlobal,
-    kCalc, kExport, kPrint,  kPuts, kLoad, 
+    kChomp, kSubstr, kEval, kFg, kBg, 
+    kJobs, kRehash, kKanjiCode, kLineField,
+    kCalc, kPrint,  kPuts, kLoad, 
     kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kSelect, kLines, kRows,
-    kAryNew, kAryAdd, kAryErase, 
-    kHashNew, kHashAdd, kHashErase, kMatch, kScan, kErase, kSub,
+    kMatch, kScan, kErase, kSub,
     kRead, 
     kCd, 
     kAdd, kDel, kSelector, kMax, kMin,
@@ -175,15 +177,6 @@ BOOL xclose(int fd);
     // gFReadBuffersΥХåեк
     // gFWriteBuffersΥХåեн񤭹Ǻ
 
-void update_ary_env(char* key);
-    // ѿˤޤĤѿ(_size)ͤ˹
-
-void clear_ary_env(char* key);
-    // ѿˤޤĤѿä
-
-void saphire_delete_same_name_var(char* name);
-    // Ʊ̾ΥХϤѿƾä
-
 int get_command_kind(char* arg0);
     // ޥ̾饳ޥIDõ
 
