@@ -52,7 +52,7 @@ char* gStatmentKindStrs[kCommand+1] = {
     "rindex", 
     "length",
     "lc",  "uc", "chomp", "substr", "eval", "fg", 
-    "bg", "obs", 
+    "bg", "jobs", 
     "rehash", 
     "kanjicode", "linefield", "calc", 
      "print",  "puts",
@@ -2724,7 +2724,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.0.0", 1);
+    setenv("SAPHIRE_VERSION", "3.0.1", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
